@@ -17,7 +17,7 @@ from ddtrace.constants import SPAN_MEASURED_KEY
 from ddtrace.contrib import dbapi
 from ddtrace.contrib import func_name
 
-from ...utils import get_argument_value
+from ...internal.utils import get_argument_value
 
 
 try:
@@ -33,8 +33,8 @@ from ddtrace.ext import http
 from ddtrace.ext import sql as sqlx
 from ddtrace.internal.compat import maybe_stringify
 from ddtrace.internal.logger import get_logger
-from ddtrace.utils.formats import asbool
-from ddtrace.utils.formats import get_env
+from ddtrace.internal.utils.formats import asbool
+from ddtrace.internal.utils.formats import get_env
 from ddtrace.vendor import wrapt
 
 from . import utils
